@@ -50,7 +50,7 @@ char last_error[ERROR_BUFFER_SIZE];
 
 void version(void)
 {
-	fprintf(stderr, "HTTPing v" VERSION ", (C) 2003-2008 folkert@vanheusden.com\n");
+	fprintf(stderr, "HTTPing v" VERSION ", (C) 2003-2009 folkert@vanheusden.com\n");
 #ifndef NO_SSL
 	fprintf(stderr, "SSL support included\n");
 #endif
@@ -325,14 +325,12 @@ int main(int argc, char *argv[])
 				return 1;
 		}
 	}
+	if (optind < argc)
+		get = argv[optind];
+
 
 	last_error[0] = 0x00;
 
-#ifndef NO_SSL
-	if (use_ssl && portnr == 80)
-		portnr = 443;
-#endif
-
 	if (!get_instead_of_head && show_Bps)
 		error_exit("-b/-B can only be used when also using -G\n");
 
@@ -340,17 +338,18 @@ int main(int argc, char *argv[])
 	{
 		char *slash, *colon;
 		char *getcopy = mystrdup(get, "get request");
-		char *http_string = "http://";
-		int http_string_len = 7;
 
-#ifndef NO_SSL
-		if (use_ssl)
+		if (strncasecmp(getcopy, "http://", 7) == 0)
 		{
-			http_string_len = 8;
-			http_string = "https://";
+			getcopy += 7;
+		}
+		else if (strncasecmp(getcopy, "https://", 8) == 0)
+		{
+			getcopy += 8;
+			use_ssl = 1;
 		}
-#endif
 
+		/*
 		if (strncasecmp(getcopy, http_string, http_string_len) != 0)
 		{
 			fprintf(stderr, "'%s' is a strange URL\n", getcopy);
@@ -359,19 +358,20 @@ int main(int argc, char *argv[])
 				fprintf(stderr, "Did you forget to add the '-l' switch to the httping commandline?\n");
 			return 2;
 		}
+		*/
 
-		slash = strchr(&getcopy[http_string_len], '/');
+		slash = strchr(getcopy, '/');
 		if (slash)
 			*slash = 0x00;
 
-		colon = strchr(&getcopy[http_string_len], ':');
+		colon = strchr(getcopy, ':');
 		if (colon)
 		{
 			*colon = 0x00;
 			portnr = atoi(colon + 1);
 		}
 
-		hostname = &getcopy[http_string_len];
+		hostname = getcopy;
 	}
 
 	if (hostname == NULL)
@@ -380,6 +380,11 @@ int main(int argc, char *argv[])
 		error_exit("No hostname/getrequest given\n");
 	}
 
+#ifndef NO_SSL
+	if (use_ssl && portnr == 80)
+		portnr = 443;
+#endif
+
 	if (get == NULL)
 	{
 #ifndef NO_SSL
