@@ -15,6 +15,7 @@
 
 #include <string.h>
 #include "error.h"
+#include "mem.h"
 #include "utils.h"
 
 #ifndef strndup
@@ -28,12 +29,3 @@ char *strndup(char *in, int size)
 	return out;
 }
 #endif
-
-char *mystrdup(char *in)
-{
-	char *out = strdup(in);
-	if (!out)
-		error_exit("strdup failed");
-
-	return out;
-}
